from gradescalculator.main import calculate_grades

def test_calculate_grades():
    grades = {
        "grade 1": {"weight": 10, "grade": 3.6},
        "grade 2": {"weight": 15, "grade": 4.6},
        "grade 3": {"weight": 25, "grade": 5.3},
        "grade 4": {"weight": 5, "grade": 4.0},
        "grade 5": {"weight": 45, "grade": 4.9}
    }
    
    precise_grade, rounded_grade = calculate_grades(grades)
    
    assert precise_grade == 4.78
    assert rounded_grade == 5.0




# gradescalculator/main.py

import argparse

def calculate_grades(grades):
    # Calculate the total weighted sum of the grades
    total_weighted_sum = sum(item["weight"] * item["grade"] for item in grades.values())

    # Calculate the total weight
    total_weight = sum(item["weight"] for item in grades.values())

    # Calculate the overall grade
    overall_grade = total_weighted_sum / total_weight

    # Round the overall grade to the nearest 0.01 and the nearest 0.5
    precise_overall_grade = round(overall_grade * 100) / 100
    rounded_overall_grade = round(overall_grade * 2) / 2

    return precise_overall_grade, rounded_overall_grade

def main():
    parser = argparse.ArgumentParser(description="Calcule la note globale à partir des notes.")
    parser.add_argument('grades', metavar='N', type=float, nargs='+', help='Liste des notes et de leurs poids sous la forme: note1 poids1 note2 poids2 ...')
    args = parser.parse_args()

    # Convert the grades to a dictionary
    grades = {}
    for i in range(0, len(args.grades), 2):
        grades[f'grade {i//2 + 1}'] = {"weight": args.grades[i+1], "grade": args.grades[i]}

    precise_grade, rounded_grade = calculate_grades(grades)
    
    print(f"Precise Overall Grade (rounded to the nearest 0.01): {precise_grade}")
    print(f"Rounded Overall Grade (rounded to the nearest 0.5): {rounded_grade}")

if __name__ == '__main__':
    main()



from setuptools import setup, find_packages

setup(
    name='gradescalculator',
    version='1.11',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'average=gradescalculator.main:main',
        ],
    },
    author='Quentin Berthet',
    author_email='quentin@berthet.ch',
    description='Un package pour calculer des notes avec des poids différents.',
    url='https://github.com/BERTHETquentin/GradesCalculator',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
